@@ -1,5 +1,6 @@
 from azureml.core import Workspace, Experiment, Run
 
+from energinetml.backend import default_backend as backend
 from energinetml.core.training import AbstractTrainingContext
 
 from .logger import AzureMlLogger
@@ -15,7 +16,7 @@ class AzureLocalTrainingContext(AbstractTrainingContext):
         self.az_run = None
 
     def train_model(self, model, tags, **kwargs):
-        az_workspace = Workspace.get(
+        az_workspace = backend.get_workspace(
             name=model.project.workspace_name,
             subscription_id=model.project.subscription_id,
             resource_group=model.project.resource_group,
