@@ -33,7 +33,7 @@ def release(run_id, model):
     """
     project = model.project
 
-    workspace = AzWorkspace.get(
+    workspace = backend.get_workspace(
         name=project.workspace_name,
         subscription_id=project.subscription_id,
         resource_group=project.resource_group,
